@@ -413,6 +413,28 @@ statusline_addstr(char *str)
 	wrefresh(bottom);
 }
 
+/*
+ * function statusline_getnstr
+ *
+ * parameters:
+ *  (char *str)
+ *   if n >= 0 str is a pointer which points a place where to store
+ *   the string, else str is ingnored
+ *  (int n)
+ *   the maximum length of the string
+ *   If n < 0 function will allocate needed space for the string.
+ *   Value 0 is not allowed for n.
+ *  (int use_filesel)
+ *   if this value is nonzero the fileselector is enabled
+ *
+ *  returns (char *)
+ *   If n < 0 a pointer to a newly allocated string is returned.
+ *   If n > 0 a nonzero value is returned if user has typed a valid
+ *   string. If not NULL value is returned. Never really use the
+ *   _pointer_ if n > 0.
+ *
+ */
+
 char *
 statusline_getnstr(char *str, int n, int use_filesel)
 {
@@ -429,7 +451,7 @@ statusline_getnstr(char *str, int n, int use_filesel)
 		return buf;
 	
 	if(buf == NULL)
-		*str=0;
+		str[0] = 0;
 	else
 		strncpy(str, buf, n);
 
@@ -437,7 +459,7 @@ statusline_getnstr(char *str, int n, int use_filesel)
 
 	free(buf);
 
-	return NULL;
+	return buf;
 }
 
 void
@@ -549,17 +571,18 @@ static void
 muttq_print_item(int item)
 {
 	char emails[MAX_EMAILS][MAX_EMAIL_LEN];
+	int i;
 
 	split_emailstr(item, emails);
 	
-	if( options_get_int("mutt_return_all_emails") ) {
-		int i;
-		for(i=0; i<MAX_EMAILS; i++)
-			if( *emails[i] )
-				printf("%s\t%s\n", emails[i],
-					database[item][NAME]);
-	} else
-		printf("%s\t%s\n", emails[0], database[item][NAME]);
+	for(i = 0; i < (options_get_int("mutt_return_all_emails") ?
+			MAX_EMAILS : 1) ; i++)
+		if( *emails[i] )
+			printf("%s\t%s\t%s\n", emails[i],
+				database[item][NAME],
+				database[item][NOTES] == NULL ? " " :
+					database[item][NOTES]
+				);
 }
 
 static int
