@@ -37,7 +37,7 @@ int		strncasecmp (const char *, const char *, size_t);
 #define show_cursor()	curs_set(1)
 
 #define safe_atoi(X)    (X == NULL) ? 0 : atoi(X)
-#define my_free(X)	{free(X); X=NULL;}
+#define my_free(X)	do {free(X); X=NULL;} while(0)
 #define safe_str(X)	X == NULL ? "" : X
 #define safe_strdup(X)	(X == NULL) ? NULL : strdup(X)
 
