@@ -73,8 +73,15 @@ conff_add_key(struct conff_node **ptr, char *key, char *value, int flags)
 			} else
 				return;
 		}
-
-	new_item = malloc(sizeof(struct conff_node));	
+	
+	 /*
+	  * out of memory - error is ingnored
+	  * NOTE: with REPLACE_KEY flag the node will be deleted in OOM
+	  * situation
+	  */
+	if( (new_item = malloc(sizeof(struct conff_node))) == NULL )
+		return;
+	
 	new_item -> key = strdup(key);
 	new_item -> value = strdup(value);
 	new_item -> next = next;
