@@ -57,7 +57,7 @@ void		print_database();
 
 #define itemcpy(dest, src)	memmove(dest, src, sizeof(list_item))
 
-#define split_emailstr(item, emails) {\
+#define split_emailstr(item, emails) do {\
 	int _i,_j,_k,len; \
 	memset(&emails, 0, sizeof(emails) ); \
 	len = strlen(database[item][EMAIL]); \
@@ -69,7 +69,7 @@ void		print_database();
 			if( _k < MAX_EMAIL_LEN -1 ) \
 				emails[_j][_k++] = database[item][EMAIL][_i]; \
 	} \
-}
+} while(0)
 
 #define have_multiple_emails(item) \
 	strchr(database[item][EMAIL], ',')
