@@ -126,12 +126,9 @@ wenter_string(WINDOW *win, const int maxlen, const int flags)
 			break;
 	}
 out:
-	if( i > 0 && str != NULL )
+	if( i >= 0 && str != NULL )
 		str[i] = 0;
 	
-	if(i == 0)
-		*str=0;
-
 	return str;
 }
 
