@@ -95,7 +95,8 @@ number_of_filters(struct abook_filter * filters)
 {
 	int i;
 
-	for(i=0; *filters[i].filtname ; i++);
+	for(i=0; *filters[i].filtname ; i++)
+		;
 
 	return i;
 }
@@ -110,7 +111,9 @@ get_real_name()
 
 	pwent = getpwnam(username);
 
-	tmp = malloc(strlen(pwent->pw_gecos) +1);
+	if( (tmp = malloc(strlen(pwent->pw_gecos) +1)) == NULL)
+		return strdup(username);
+
 	rtn = sscanf(pwent->pw_gecos, "%[^,]", tmp);
 	if (rtn == EOF || rtn == 0) {
 		free(tmp);
@@ -559,9 +562,11 @@ ldif_fix_string(char *str)
  * mutt alias import filter
  */
 
-#define MUTT_ALIAS	0
-#define MUTT_NAME	1
-#define MUTT_EMAIL	2
+enum {
+	MUTT_ALIAS,
+	MUTT_NAME,
+	MUTT_EMAIL
+};
 
 static void
 remove_newlines(char *buf)
@@ -599,7 +604,9 @@ mutt_read_line(FILE *in, char **alias, char **rest)
 	while( ! ISSPACE(*ptr) )
 		ptr++;
 
-	*alias = malloc(ptr-tmp+1);
+	if( (*alias = malloc(ptr-tmp+1)) == NULL)
+		return 1;
+
 	strncpy(*alias, tmp, ptr-tmp);
 	*(*alias+(ptr-tmp)) = 0;
 
