@@ -102,10 +102,19 @@ print_list_line(int i, int line)
 		mvwaddnstr(list, line, EMAILPOS, tmp, real_emaillen);
 	}
 
-	if(extra_column > 2 && extra_column < ITEM_FIELDS)
+	if(extra_column > 2 && extra_column < ITEM_FIELDS) {
+		if( !database[i][extra_column] ) {
+			int extra_alternative =
+				options_get_int("extra_alternative");
+			
+			if(extra_alternative > 2 &&
+					extra_alternative < ITEM_FIELDS)
+				extra_column = extra_alternative;
+		}
 		mvwaddnstr(list, line, EXTRAPOS,
 				safe_str(database[i][extra_column]),
 				EXTRALEN);
+	}
 
 	scrollok(list, TRUE);
 }
