@@ -21,8 +21,10 @@ int		selected_items();
 void		invert_selection();
 
 
-#define MOVE_ITEM_UP    0x01
-#define MOVE_ITEM_DOWN  0x02
+enum {
+	MOVE_ITEM_UP,
+	MOVE_ITEM_DOWN
+};
 
 #define LIST_TOP        3
 #define LIST_BOTTOM     (LINES-3)
@@ -31,8 +33,8 @@ void		invert_selection();
 #define LIST_COLS	COLS
 
 #define NAMEPOS		2
-#define EMAILPOS        options_get_int("list", "emailpos")
-#define EXTRAPOS	options_get_int("list", "extrapos")
+#define EMAILPOS        options_get_int("emailpos")
+#define EXTRAPOS	options_get_int("extrapos")
 
 #define NAMELEN		(EMAILPOS-NAMEPOS -1)
 #define EMAILLEN        (EXTRAPOS-EMAILPOS -1)
