@@ -1,13 +1,13 @@
 #ifndef _OPTIONS_H
 #define _OPTIONS_H
 
-#define RCFILE		".abook.conf"
-#define SYSWIDE_RCFILE	"/etc/abook.conf"
+#define RCFILE		".abookrc"
+#define SYSWIDE_RCFILE	"/etc/abookrc"
 
 #include "conff.h"
 
-int	options_get_int(char *section, char *key);
-char	*options_get_str(char *section, char *key);
+int	options_get_int(char *key);
+char	*options_get_str(char *key);
 void	init_options();
 void	edit_options();
 void	close_config();
